@@ -41,24 +41,28 @@ def make_node(
     # running_var: gs.Variable = graph_node.outputs[2] # disuse
 
     if hasattr(scale, 'inputs') \
+        and len(scale.inputs) > 0 \
         and hasattr(scale.inputs[0], 'attrs') \
         and 'value' in scale.inputs[0].attrs \
         and hasattr(scale.inputs[0].attrs['value'], 'values'):
         scale = scale.inputs[0].attrs['value']
 
     if hasattr(B, 'inputs') \
+        and len(B.inputs) > 0 \
         and hasattr(B.inputs[0], 'attrs') \
         and 'value' in B.inputs[0].attrs \
         and hasattr(B.inputs[0].attrs['value'], 'values'):
         B = B.inputs[0].attrs['value']
 
     if hasattr(input_mean, 'inputs') \
+        and len(input_mean.inputs) > 0 \
         and hasattr(input_mean.inputs[0], 'attrs') \
         and 'value' in input_mean.inputs[0].attrs \
         and hasattr(input_mean.inputs[0].attrs['value'], 'values'):
         input_mean = input_mean.inputs[0].attrs['value']
 
     if hasattr(input_var, 'inputs') \
+        and len(input_var.inputs) > 0 \
         and hasattr(input_var.inputs[0], 'attrs') \
         and 'value' in input_var.inputs[0].attrs \
         and hasattr(input_var.inputs[0].attrs['value'], 'values'):
